@@ -7,8 +7,11 @@ class Config(object):
         self.path = path
         if "%APPDATA%" in self.path:
             self.path = self.path.replace("%APPDATA%", str(os.getenv("APPDATA")))
-        if not tools.existFile(self.path):
-            tools.createDirectory(self.path)
+        if not tools.existDirectory(self.path):
+            try:
+                tools.createDirectory(self.path)
+            except:
+                pass
         if not tools.existFile(self.path + "config.json"):
             tools.createFile(self.path + "config.json")
             tools.saveJson(self.path + "config.json", default_config)
