@@ -31,7 +31,7 @@ class Client:
             if self.error == 0:
                 self.send({"METHOD": "AUTHENTICATION", "CLIENT_ID": self.clientID, "CLIENT_TYPE": self.clientType, "PASSWORD": self.password})
             while self.error == 0:
-                lastData = None
+                lastData = "None"
                 try:
                     recvData = self.clientSocket.recv(32768)
                     recvData = str(recvData, "utf-8")
