@@ -28,7 +28,7 @@ class Server:
         def clientTask(clientSocket, address):
             logger.log("§8[§eSERVER§8] §aClient connected from §6" + str(address))
             while True:
-                lastData = None
+                lastData = "None"
                 try:
                     recvData = clientSocket.recv(32768)
                     recvData = str(recvData, "utf-8")
